@@ -478,14 +478,23 @@ def analyze(vulnerability,
   for affected_package in vulnerability.affected:
     versions = []
     for affected_range in affected_package.ranges:
+      if affected_package.package.ecosystem in ecosystems.SEMVER_ECOSYSTEMS:
+        # Replace erroneous range type.
+        affected_range.type = vulnerability_pb2.Range.SEMVER
+
       if affected_range.type in (vulnerability_pb2.Range.ECOSYSTEM,
                                  vulnerability_pb2.Range.SEMVER):
         # Enumerate ECOSYSTEM and SEMVER ranges.
         ecosystem_helpers = ecosystems.get(affected_package.package.ecosystem)
         if ecosystem_helpers:
-          versions.extend(
-              enumerate_versions(affected_package.package.name,
-                                 ecosystem_helpers, affected_range))
+          try:
+            versions.extend(
+                enumerate_versions(affected_package.package.name,
+                                   ecosystem_helpers, affected_range))
+          except ecosystems.EnumerateError:
+            # Allow non-retryable enumeration errors to occur (e.g. if the
+            # package no longer exists).
+            pass
         else:
           logging.warning('No ecosystem helpers implemented for %s',
                           affected_package.package.ecosystem)
