@@ -331,17 +331,22 @@ class Bug(ndb.Model):
         affected_package.package.purl = purl_helpers.package_to_purl(
             affected_package.package.ecosystem, affected_package.package.name)
 
-    self.project = [
+    self.project = list({
         pkg.package.name for pkg in self.affected_packages if pkg.package.name
-    ]
-    self.ecosystem = [
+    })
+    self.project.sort()
+
+    self.ecosystem = list({
         pkg.package.ecosystem
         for pkg in self.affected_packages
         if pkg.package.ecosystem
-    ]
-    self.purl = [
+    })
+    self.ecosystem.sort()
+
+    self.purl = list({
         pkg.package.purl for pkg in self.affected_packages if pkg.package.purl
-    ]
+    })
+    self.purl.sort()
 
     for project in self.project:
       search_indices.update(self._tokenize(project))
@@ -349,7 +354,11 @@ class Bug(ndb.Model):
     for ecosystem in self.ecosystem:
       search_indices.update(self._tokenize(ecosystem))
 
-    self.search_indices = sorted(list(search_indices))
+    for alias in self.aliases:
+      search_indices.update(self._tokenize(alias))
+
+    self.search_indices = list(set(search_indices))
+    self.search_indices.sort()
 
     self.affected_fuzzy = []
     self.semver_fixed_indexes = []
@@ -382,6 +391,9 @@ class Bug(ndb.Model):
 
         self.has_affected |= (affected_range.type in ('SEMVER', 'ECOSYSTEM'))
 
+    self.affected_fuzzy = list(set(self.affected_fuzzy))
+    self.affected_fuzzy.sort()
+
     if not self.last_modified:
       self.last_modified = utcnow()
 
